==> ZenTaoPMS.15.0.2.zip: zentaopms/module/personnel/lang/en.php <==
<?php
$lang->personnel->common     = 'Program Personnel';
$lang->personnel->accessible = 'Acess List';
$lang->personnel->invest    = 'Input Resource';
$lang->personnel->department = 'Department';
$lang->personnel->realName   = 'Name';
$lang->personnel->userName   = 'Account';
$lang->personnel->job        = 'Position';
$lang->personnel->genders    = 'Gender';
$lang->personnel->project    = 'Project';
$lang->personnel->search     = 'Search';
$lang->personnel->delete     = 'Remove';
$lang->personnel->role       = 'Role';

$lang->personnel->name          = 'User';
$lang->personnel->projects      = 'Projects';
$lang->personnel->executions    = 'Executions';
$lang->personnel->workingHours  = 'Hours';
$lang->personnel->task          = 'Task';
$lang->personnel->bug           = 'Bug';
$lang->personnel->createStories = 'Story';
$lang->personnel->risk          = 'Risk';
$lang->personnel->issue         = 'Issue';
$lang->personnel->invest       = 'Input';
$lang->personnel->left          = 'Remained';
$lang->personnel->created       = 'Created';
$lang->personnel->finished      = 'Finished';
$lang->personnel->wait          = 'Pending';
$lang->personnel->resolved      = 'Resolved';
$lang->personnel->UR            = $lang->URCommon;
$lang->personnel->SR            = $lang->SRCommon;

$lang->personnel->whitelist      = 'Whitelist';
$lang->personnel->addWhitelist   = 'Add Whitelist';
$lang->personnel->unbindWhitelist = 'Remove Whitelist';
$lang->personnel->confirmDelete  = 'Confirm removal of the user from the whitelist?';

$lang->personnel->openedPGMTip = 'The program is public and can be accessed by users with Program privileges.';

==> ZenTaoPMS.16.3.zip: zentaopms/module/personnel/lang/en.php <==
<?php
$lang->personnel->common     = 'Program Personnel';
$lang->personnel->accessible = 'Acess List';
$lang->personnel->invest     = 'Input Resource';
$lang->personnel->department = 'Department';
$lang->personnel->realName   = 'Name';
$lang->personnel->userName   = 'Account';
$lang->personnel->job        = 'Position';
$lang->personnel->genders    = 'Gender';
$lang->personnel->project    = 'Project';
$lang->personnel->search     = 'Search';
$lang->personnel->delete     = 'Remove';
$lang->personnel->role       = 'Role';

$lang->personnel->name          = 'User';
$lang->personnel->projects      = 'Projects';
$lang->personnel->executions    = 'Executions';
$lang->personnel->workingHours  = 'Hours';
$lang->personnel->task          = 'Task';
$lang->personnel->bug           = 'Bug';
$lang->personnel->createStories = 'Story';
$lang->personnel->risk          = 'Risk';
$lang->personnel->issue         = 'Issue';
$lang->personnel->invest       = 'Input';
$lang->personnel->left          = 'Remained';
$lang->personnel->created       = 'Created';
$lang->personnel->finished      = 'Finished';
$lang->personnel->wait          = 'Pending';
$lang->personnel->resolved      = 'Resolved';
$lang->personnel->UR            = $lang->URCommon;
$lang->personnel->SR            = $lang->SRCommon;

$lang->personnel->whitelist       = 'Whitelist';
$lang->personnel->addWhitelist    = 'Add Whitelist';
$lang->personnel->unbindWhitelist = 'Remove Whitelist';
$lang->personnel->confirmDelete   = 'Confirm removal of the user from the whitelist?';
$lang->personnel->copy            = 'Copy Whitelist';

$lang->personnel->openedPGMTip     = 'The program is public and can be accessed by users with Program privileges.';
$lang->personnel->selectObjectTips = 'Select %s to copy its whitelist';
